from django.conf import settings
from django.core.management.base import BaseCommand
from djangobp.editsettings import CodeEditor
import MySQLdb
import os

class Command(BaseCommand):
    args = 'database_name user password --superuser=superuser'
    help = '''create database named database_name using user and password. 
if superuser is specified, this command will be executed by superuser.'''

    def handle(self, *args, **options):
        database = args[0]
        user = args[1]
        password = args[2]
#        if 'superuser' in options: user = options['superuser']

        db = MySQLdb.connect(user=user, passwd=password)
        cursor = db.cursor()
        print 'CREATE SCHEMA `%s` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci' % database
        cursor.execute('CREATE SCHEMA `%s` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci' % database)
        cursor.close()
        db.close()
        print 'database %s created.' % database

        project_path = os.path.dirname(os.path.normpath(os.sys.modules[settings.SETTINGS_MODULE].__file__))
        edit = CodeEditor(project_path + os.sep + 'settings.py')
        edit.go_line('DATABASES = {')
        edit.go_line("'default': {")
        edit.replace_line("'ENGINE': 'django.db.backends.'", "'ENGINE': 'django.db.backends.mysql'")
        edit.replace_line("'NAME': ''", "'NAME': '%s'" % database)
        edit.replace_line("'USER': ''", "'USER': '%s'" % user)
        edit.replace_line("'PASSWORD': ''", "'PASSWORD': '%s'" % password)
        edit.commit()
        
        print "edited settings.py"


from django.contrib.auth.decorators import login_required
from django.http import HttpResponse
from djangobp.makohelper import render_to_response

@login_required
def index(request):
    return render_to_response('useract.html', locals())


from django.http import HttpResponse, HttpResponseServerError
from django.utils import importlib
from django.utils.functional import curry
from mako import exceptions
from mako.lookup import TemplateLookup
from mako.template import Template
import datetime
import os
import simplejson
import sys
import pkgutil
import types
import inspect
from django.conf.urls import include, url

controller_resource_method_pattern = r'(?P<controller>[^/\?\&.]+)?(/(?P<resource_id>[^/\?\&.]+))?(/(?P<method>[^/\?\&.]+))?(?P<format>\.(\w+)$)?'

def router(controllers_root):
    return curry(route, controllers_root)

def route(controllers_root, request, controller=None, resource_id=None, method=None, format=None):
    request.format = format[1:] if format is not None else 'plain'

    request.app_name = controllers_root.__name__[:controllers_root.__name__.rfind('.')]
    if controller:
        module_name = controllers_root.__name__ + '.' + controller
    else:
        module_name = controllers_root.__name__
    
    __import__(module_name)

    if not method:
        if resource_id: 
            if hasattr(sys.modules[module_name], resource_id):
                method = resource_id
                resource_id = None
            else:
                method = 'show'
        else: method = 'index'

    return getattr(sys.modules[module_name], method)(request, resource_id)

def discover_controllers(package):
    urls = []
    __import__(package)

    if hasattr(sys.modules[package], 'index'):
        urls.append(url('^$', getattr(sys.modules[package], 'index')))
    
    for _, name, _ in pkgutil.iter_modules([sys.modules[package].__path__[0]]):
        __import__(package + '.' + name)
        
        controller = sys.modules[package + '.' + name]
        
        for member in dir(controller):
            func = getattr(controller, member)
            if not inspect.isfunction(func): continue
            args = inspect.getargspec(func).args
            
            if len(args) == 0 or args[0] != 'request': continue
            
            urls.append(url(name + '/(?P<resource_id>[^/\?\&.]+)/' + member + '/?$', func))
            urls.append(url(name + '/' + member + '/?$', func))

        if 'show' in dir(controller):
            urls.append(url(name + '/(?P<resource_id>[^/\?\&.]+)/?$', getattr(controller, 'show')))
        if 'index' in dir(controller):
            urls.append(url(name + '$', getattr(controller, 'index')))
            
                
    return include(urls)
    
def render_to_response(filename, dictionary):
    # using app_name that is set by route()
    app_name = dictionary['request'].app_name
    templates = importlib.import_module(app_name + '.templates')

    try:
        template_lookup = TemplateLookup(directories=[templates.__path__[0]], input_encoding='utf8')
        template = Template(filename=templates.__path__[0] + os.sep + filename, input_encoding='utf8', output_encoding='utf8', template_lookup=template_lookup, imports=['from djangobp.textutil import gettext as _'])
        return HttpResponse(template.render(**dictionary))
    except:
        return HttpResponseServerError(exceptions.html_error_template().render())

@DeprecationWarning
class HttpResponseJSON(HttpResponse):
    def __init__(self, data):
        HttpResponse.__init__(self, simplejson.dumps(data, ensure_ascii=False, cls=JSONDateEncoder), content_type='application/json')

class JSONDateEncoder(simplejson.JSONEncoder):
    def default(self, obj):
        if isinstance(obj, datetime.datetime):
            return obj.isoformat() + 'Z'
#            return obj.strftime('%Y-%m-%dT%H:%M:%S')
        else:
            return simplejson.JSONEncoder.default(self, obj)
        
def render_to_json(data):
    return HttpResponseJSON(data)




from social_auth.context_processors import social_auth_by_type_backends
from django.core.urlresolvers import reverse
from django.contrib.auth import logout as auth_logout
from django.http import HttpResponseRedirect
from django.core.context_processors import csrf
from djangobp.makohelper import render_to_response
from django.template.defaulttags import csrf_token
from django.template.base import Template
from django.template.context import RequestContext

def login(request):
    reverse_url = reverse
    l = locals()
    l.update(social_auth_by_type_backends(request))
    return render_to_response('accounts/login.html', l, RequestContext(request))

def logout(request):
    """Logs out user"""
    auth_logout(request)
    return HttpResponseRedirect('/')



from distutils.file_util import copy_file
from django.core.management.base import BaseCommand
from djangobp.editsettings import install_app, CodeEditor
from django.conf import settings
import djangobp
import importlib
import os
from distutils.dir_util import copy_tree

class Command(BaseCommand):
    args = 'app'
    help = 'install django-social-auth'

    def handle(self, *args, **options):
        app_name = args[0]
        module = importlib.import_module(app_name)
        path = os.path.dirname(module.__file__) + os.sep
        
        project_path = os.path.dirname(os.path.normpath(os.sys.modules[settings.SETTINGS_MODULE].__file__))
        
        install_app('social_auth')

        copy_tree(os.path.dirname(djangobp.__file__) + os.sep + 'scaffold/socialauth/templates/accounts', path + '/templates/accounts', update=True)

        copy_file(os.path.dirname(djangobp.__file__) + os.sep + 'scaffold/socialauth/controllers/accounts.py', path + '/controllers', update=True)
        copy_file(os.path.dirname(djangobp.__file__) + os.sep + 'scaffold/scaffold/socialauthsettings.py', project_path, update=True)

        urls_edit = CodeEditor(path + 'urls.py')
        urls_edit.insert_line("url(r'', include('social_auth.urls')),", 'urlpatterns')
        urls_edit.commit()

        settings_edit = CodeEditor(project_path + os.sep + 'settings.py')
        settings_edit.append_line("from socialauthsettings import *")
        settings_edit.commit()
        
        # TODO copy controllers/accounts.py
        # TODO copy templates/accounts/login.html
        # TODO urls social auth
        # TODO django-social-auth settings
        
        


import datetime

date_isoformat = '%Y-%m-%dT%H:%M:%S.%fZ'
def parse_dt(s):
    return datetime.datetime.strptime(s, date_isoformat)

def dthandler(obj):
    if isinstance(obj, datetime.datetime):
        return obj.isoformat() + 'Z'
    else:
        raise TypeError, 'Object of type %s with value of %s is not JSON serializable' % (type(obj), repr(obj))



from django.core.management.base import BaseCommand
from djangobp.editsettings import install_app

class Command(BaseCommand):
    args = 'app_name'
    help = 'installapp app_name'

    def handle(self, *args, **options):
        install_app(args[0])

            



from django.conf.urls import patterns, include, url
from djangobp.route import discover_controllers

urlpatterns = patterns('',
    url(r'', include('social_auth.urls')),
    (r'', discover_controllers('socialauth.controllers')),
)



from django.http import HttpResponseRedirect
from djangobp.makohelper import render_to_response
from django.forms.models import ModelForm, ModelChoiceField
from django.forms.widgets import HiddenInput
from django.contrib.auth.models import User
from django.core.paginator import Paginator
from django.core.urlresolvers import reverse
from djangobp.scaffold.model.models import Sample
from django.template.context import RequestContext

class SampleForm(ModelForm):
    class Meta:
        model = Sample

model_class = Sample
controller = __name__.split('.')[-1]
form_class = SampleForm

def path():
    return reverse(__name__ + '.index')
        
page_size = 20

def index(request):
    page = int(request.GET.get('page', 1))
    paginator = Paginator(model_class.objects.all(), page_size)
    current_page = paginator.page(page)
    
    return render_to_response(controller + '/index.html', locals())

def show(request, resource_id):
    item = model_class.objects.get(id=resource_id)
    return render_to_response(controller + '/show.html', locals())

def new(request):
    form = form_class(initial={'owner':request.user})
    return render_to_response(controller + '/new.html', locals(), RequestContext(request))

def create(request):
    form = form_class(request.POST)
    if form.is_valid():
        item = form.save()
        return HttpResponseRedirect(path() + '/%s' % item.id)
    else:
        return render_to_response(controller + '/new.html', locals())
    

def edit(request, resource_id):
    item = model_class.objects.get(id=resource_id)
    form = form_class(instance=item)
    return render_to_response(controller + '/edit.html', locals(), RequestContext(request))

def update(request, resource_id):
    item = model_class.objects.get(id=resource_id)
    form = form_class(request.POST, instance=item)
    
    if form.is_valid():
        item = form.save()
        return HttpResponseRedirect(path() + '/%s' % item.id)
    else:
        return render_to_response(controller + '/edit.html', locals())

def delete(request, resource_id):
    model_class.objects.filter(id=resource_id).delete()
    return HttpResponseRedirect(path())



AUTHENTICATION_BACKENDS = (
    'social_auth.backends.twitter.TwitterBackend',
    'social_auth.backends.facebook.FacebookBackend',
    'social_auth.backends.google.GoogleOAuthBackend',
    'social_auth.backends.google.GoogleOAuth2Backend',
    'social_auth.backends.google.GoogleBackend',
    'social_auth.backends.yahoo.YahooBackend',
    'social_auth.backends.contrib.linkedin.LinkedinBackend',
    'social_auth.backends.contrib.livejournal.LiveJournalBackend',
    'social_auth.backends.contrib.orkut.OrkutBackend',
    'social_auth.backends.contrib.foursquare.FoursquareBackend',
    'social_auth.backends.contrib.github.GithubBackend',
    'social_auth.backends.OpenIDBackend',
    'django.contrib.auth.backends.ModelBackend',
)

SOCIAL_AUTH_ENABLED_BACKENDS = ('google', 'facebook', 'twitter')

TWITTER_CONSUMER_KEY         = ''
TWITTER_CONSUMER_SECRET      = ''
FACEBOOK_APP_ID              = ''
FACEBOOK_API_SECRET          = ''
LINKEDIN_CONSUMER_KEY        = ''
LINKEDIN_CONSUMER_SECRET     = ''
ORKUT_CONSUMER_KEY           = ''
ORKUT_CONSUMER_SECRET        = ''
GOOGLE_CONSUMER_KEY          = ''
GOOGLE_CONSUMER_SECRET       = ''
GOOGLE_OAUTH2_CLIENT_ID      = ''
GOOGLE_OAUTH2_CLIENT_SECRET  = ''
FOURSQUARE_CONSUMER_KEY      = ''
FOURSQUARE_CONSUMER_SECRET   = ''
GITHUB_APP_ID                = ''
GITHUB_API_SECRET            = ''

#LOGIN_URL          = '/login-form/'
#LOGIN_REDIRECT_URL = '/'
#LOGIN_ERROR_URL    = '/login-error/'

#SOCIAL_AUTH_COMPLETE_URL_NAME  = 'socialauth_complete'
#SOCIAL_AUTH_ASSOCIATE_URL_NAME = 'socialauth_associate_complete'



from djangobp.makohelper import render_to_response

def index(request):
    method = 'index'
    resource_id = None
    return render_to_response('hello.html', locals())

def show(request, resource_id):
    method = 'show'
    return render_to_response('hello.html', locals())

def custom(request, resource_id):
    method = 'custom'
    return render_to_response('hello.html', locals())
    


from selenium import webdriver
import time
from selenium.common.exceptions import TimeoutException
import os
from selenium.webdriver.common.desired_capabilities import DesiredCapabilities

firefox_profiles_path = os.environ['HOME'] + os.sep + 'Library/Application Support/Firefox/Profiles'

def webdriver_firefox():
    
    try:
        f = open(os.environ['HOME'] + os.sep + '.selenium_port', 'r')
        port = f.read()
        f.close()
        driver = webdriver.Remote(command_executor='http://127.0.0.1:%s/hub' % port, desired_capabilities=DesiredCapabilities.FIREFOX)
    except:
        default_profile = filter(lambda s: s.find('.selenium') >= 0, os.listdir(firefox_profiles_path))[0]
        profile = webdriver.FirefoxProfile(firefox_profiles_path + os.sep + default_profile)
        driver = webdriver.Firefox(profile)
        f = open(os.environ['HOME'] + os.sep + '.selenium_port', 'w')
        f.write(str(profile.port))
        f.close()
    return driver

def wait_until(func, timeout=3):
    print func
    while timeout > 0:
        if func(): return True
        time.sleep(0.1)
        timeout -= 0.1
        
    raise TimeoutException()



# coding: utf8
from django.core.management import execute_manager
import os
import sys

class Fixture(object):
    def __init__(self, settings):
        self.settings = settings
        path = os.path.dirname(settings.__file__)
        sys.path.insert(0, path)
        os.environ['DJANGO_SETTINGS_MODULE'] = 'settings'

    def reset(self, app_name):
        execute_manager(self.settings, ['', 'reset', app_name, '--noinput'])

    def load_json(self, name):
        pass
#        execute_manager(self.settings, ['', 'loaddata', '%s/pytmon/spec/fixtures/%s.json' % (path, name)])


from django.core.management.base import BaseCommand
import importlib
import os
from distutils.dir_util import copy_tree
import djangobp
from distutils.file_util import copy_file
from djangobp.editsettings import CodeEditor

class Command(BaseCommand):
    args = 'modelclass'
    help = 'scaffold controller and views for specified model'

    def handle(self, *args, **options):
        app_name = args[0].split('.')[0]
        module = importlib.import_module(app_name)
        path = os.path.dirname(module.__file__) + os.sep
        model_class = get_class(args[0])
        controller = model_class.__name__.lower()

        copy_tree(os.path.dirname(djangobp.__file__) + os.sep + 'scaffold/model/templates/sample', path + '/templates/' + controller , update=True)
        copy_tree(os.path.dirname(djangobp.__file__) + os.sep + 'scaffold/model/templates/common', path + '/templates/common', update=True)
        copy_file(os.path.dirname(djangobp.__file__) + os.sep + 'scaffold/model/controllers/sample.py', path + '/controllers/' + controller + '.py', update=True)

        controller_edit = CodeEditor(path + '/controllers/' + controller + '.py')
        controller_edit.replace_all('from djangobp.scaffold.model.models import Sample', 'from %s import %s' % (model_class.__module__, model_class.__name__))
        controller_edit.replace_all('Sample',  model_class.__name__)
        controller_edit.commit()

def get_class( kls ):
    parts = kls.split('.')
    module = ".".join(parts[:-1])
    m = __import__( module )
    for comp in parts[1:]:
        m = getattr(m, comp)            
    return m


from django.conf import settings
import importlib
import os
import re

def install_app(app_name):
    try:
        importlib.import_module(app_name)
    except:
        print 'cannot import %s' % app_name
        return
    
    project_path = os.path.dirname(os.path.normpath(os.sys.modules[settings.SETTINGS_MODULE].__file__))
    settings_edit = CodeEditor(project_path + os.sep + 'settings.py')
    settings_edit.insert_line("    '%s'," % app_name, 'INSTALLED_APPS')
    settings_edit.commit()
    print "edited " + project_path + os.sep + 'settings.py'
        
class CodeEditor(object):
    
    def __init__(self, filename):
        self.filename = filename
        source = open(filename, 'r').read()
        self.lines = source.splitlines()
        self.cursor = 0

    def insert_tuple_element(self, name, value):
        for index, line in enumerate(self.lines):
            if line.strip().startswith(name):
                insert_index = index + 1
                break
        
        self.lines.insert(insert_index, '    ' + repr(value) + ',')

    def go_line(self, expr):
        for index, l in enumerate(self.lines[self.cursor:], self.cursor):
            if expr in l:
                self.cursor = index
                break
    
    def replace_all(self, expr, replacement):
        for index, l in enumerate(self.lines, self.cursor):
            if expr in l:
                self.lines[index] = l.replace(expr, replacement)
                
    def replace_line(self, expr, replacement):
        for index, l in enumerate(self.lines[self.cursor:], self.cursor):
            if expr in l:
                self.cursor = index
                break
            
        self.lines[self.cursor] = self.lines[self.cursor].replace(expr, replacement)
        
    def insert_line(self, line, after):
        if line in self.lines: return
        
        insert_index = 0
        for index, l in enumerate(self.lines[self.cursor:], self.cursor):
            if re.match(after, l):
                insert_index = index + 1
                break;
        self.lines.insert(insert_index, line)

    def append_line(self, line):
        self.lines.append(line)
        
    def to_source(self):
        return '\n'.join(self.lines)
    
    def commit(self):
        open(self.filename, 'w').write(self.to_source())


'''
Created on 2012. 10. 31.

@author: youngrok
'''
from __future__ import unicode_literals
from bson.objectid import ObjectId
import math

class UserMessageException(Exception):
    pass

class ObjectNotFound(UserMessageException):
    pass


class Model(dict):
    collection = None
    
    @classmethod
    def find_by_id(cls, object_id):
        try:
            return cls(cls.collection.find_one(by_id(object_id)))
        except:
            raise ObjectNotFound('%s not found.' % cls.__name__)

    @classmethod
    def find_one(cls, spec={}, *args, **kwargs):
        obj = cls.collection.find_one(spec, *args, **kwargs)
        if obj:
            return cls(obj)
        else:
            raise ObjectNotFound('%s not found.' % cls.__name__)

    @classmethod
    def find(cls, spec={}, *args, **kwargs):
        return cls.collection.find(spec, *args, **kwargs)
        
    @classmethod
    def create(cls, data):
        _id = cls.collection.insert(data)
        obj = cls.collection.find_one({'_id':_id})
        return cls(obj)

    @classmethod
    def get_or_create(cls, data):
        if cls.find(data).count():
            return cls.find_one(data)
        
        _id = cls.collection.insert(data)
        obj = cls.collection.find_one({'_id':_id})
        return cls(obj)
    
    def save(self):
        self.collection.save(self)

    def __getattr__(self, key):
        return self[key]

def by_id(object_id):
    return {'_id':ObjectId(object_id)}
        
def distance(source, target):
    dis = math.sqrt(math.pow((source['latitude']-target['latitude']), 2)+math.pow((source['longitude']-target['longitude']), 2))
    return round(dis*1110) / 10.0



from bson.objectid import ObjectId
from django.http import HttpResponse, HttpResponseServerError
from djangobp.mongomodel import UserMessageException
import datetime
import logging
import simplejson
import openpyxl
import tempfile
import os
from django.forms.models import model_to_dict

class HttpResponseJSON(HttpResponse):
    def __init__(self, data):
        HttpResponse.__init__(self, simplejson.dumps(data, ensure_ascii=False, cls=BSONEncoder), content_type='application/json')

class HttpResponseExcel(HttpResponse):
    def __init__(self, title, queryset, fields, headers=None):
        HttpResponse.__init__(self, mimetype="application/ms-excel")
        self['Content-Disposition'] = 'attachment; filename=%s.xlsx' % title.encode('utf8')
        workbook = openpyxl.workbook.Workbook(optimized_write=True)
        worksheet = workbook.create_sheet()
        worksheet.title = title
        if headers: 
            worksheet.append(headers)
        else:
            worksheet.append(fields)

        for model in queryset:
            result = []
            for field in fields:
                value = getattr(model, field)
                value = value.strftime('%Y.%m.%d %H:%M:%S') if type(value) == datetime else value
                value = '' if value is None else value
                value = '%s' % (value)
                result.append(value)
            worksheet.append(result)

        f = tempfile.NamedTemporaryFile(delete=True)
        workbook.save(f)
        f.seek(0, os.SEEK_SET)
        self.write(f.read())
        f.close()

def admin_export_as_excel(modeladmin, request, queryset):
    return HttpResponseExcel(request.path.replace('/', '_'), queryset, modeladmin.list_display)

class BSONEncoder(simplejson.encoder.JSONEncoder):
    def default(self, obj):
        if isinstance(obj, datetime.datetime):
            return obj.isoformat() + 'Z'
#            return obj.strftime('%Y-%m-%dT%H:%M:%S')
        elif isinstance(obj, ObjectId) :
            return str(obj)
        else:
            return simplejson.JSONEncoder.default(self, obj)

#simplejson.JSONEncoder = BSONEncoder

logger = logging.getLogger(__name__)

class ErrorLoggingMiddleWare(object):
    def process_exception(self, request, exception):
        if request.path.startswith('/api'):
            if isinstance(exception, UserMessageException):
                return HttpResponseJSON({'error': {'message': exception.message}})
            logger.exception(exception)
            print 'exception:', exception.message
            return HttpResponseServerError(exception.message)

def to_json(obj):
    return simplejson.dumps(obj, indent=4)


from djangobp.makohelper import render_to_response
from django.http import HttpResponseRedirect

class GenericModelController(object):
    def __init__(self, model, name=None):
        self.model = model
        if name:
            self.name = name
        else:
            self.name = model.__name__.lower()
        
    def index(self, request):
        objects = self.model.objects.all()
        return render_to_response('/%s/index.html' % self.name, locals())
    
    def show(self, request, resource_id):
        item = self.model.objects.get(id=resource_id)
        return render_to_response('/%s/show.html' % self.name, locals())
    
    def new(self, request):
        return render_to_response('/%s/new.html' % self.name, locals())
        
    def create(self, request):
        item = self.model.objects.create()
        return HttpResponseRedirect('/%s/%s' % (self.name, item.id))
        
    def edit(self, request):
        return render_to_response('/%s/edit.html' % self.name, locals())

    def update(self, request, resource_id):
        item = self.model.objects.get(id=resource_id)
        return HttpResponseRedirect('/%s/%s' % (self.name, item.id))
        
    def delete(self, request, resource_id):
        self.model.objects.filter(id=resource_id).delete()
        return HttpResponseRedirect('/%s' % (self.name,))


from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from django.http import HttpResponse, HttpResponseServerError
from django.utils.importlib import import_module
from mako.lookup import TemplateLookup
from mako.template import Template
from mako import exceptions
import os
import sys

app_template_dirs = []
fs_encoding = sys.getfilesystemencoding() or sys.getdefaultencoding()

for app in settings.INSTALLED_APPS:
    try:
        mod = import_module(app)
    except ImportError, e:
        raise ImproperlyConfigured('ImportError %s: %s' % (app, e.args[0]))
    template_dir = os.path.join(os.path.dirname(mod.__file__), 'templates')
    if os.path.isdir(template_dir):
        app_template_dirs.append(template_dir.decode(fs_encoding))

template_lookup = TemplateLookup(directories=app_template_dirs, input_encoding='utf8', output_encoding='utf8', imports=['from djangobp.textutil import gettext as _'])
def render_to_response(filename, dictionary, context_instance=None):

    if context_instance:
        for context_dict in context_instance.dicts:
            dictionary.update(context_dict)
    try:
        template = template_lookup.get_template(filename)
        return HttpResponse(template.render(**dictionary))
    except:
        return HttpResponseServerError(exceptions.html_error_template().render())
    


from django.core.management.base import BaseCommand
import importlib
import os
import djangobp
from distutils.dir_util import copy_tree
from distutils.file_util import copy_file
from djangobp.editsettings import CodeEditor
from django.conf import settings

class Command(BaseCommand):
    args = 'app'
    help = 'fill boilerplate codes for quick start'

    def handle(self, *args, **options):
        app_name = args[0]
        module = importlib.import_module(app_name)
        path = os.path.dirname(module.__file__) + os.sep
        
        copy_tree(os.path.dirname(djangobp.__file__) + os.sep + 'scaffold/app/controllers', path + 'controllers', update=True)
        copy_tree(os.path.dirname(djangobp.__file__) + os.sep + 'scaffold/app/templates', path + '/templates', update=True)
        copy_tree(os.path.dirname(djangobp.__file__) + os.sep + 'scaffold/app/static', path + '/static', update=True)
        
        copy_file(os.path.dirname(djangobp.__file__) + os.sep + 'scaffold/app/urls.py', path, update=True)
        
        urls_edit = CodeEditor(path + 'urls.py')
        urls_edit.replace_all('app', app_name)
        urls_edit.commit()
        project_path = os.path.dirname(os.path.normpath(os.sys.modules[settings.SETTINGS_MODULE].__file__))
        main_urls_edit = CodeEditor(project_path + os.sep + 'urls.py')
        main_urls_edit.insert_line("    (r'', include('%s'))," % (app_name + '.urls'), after='urlpatterns')
        main_urls_edit.commit()
        
        settings_edit = CodeEditor(project_path + os.sep + 'settings.py')
        settings_edit.insert_line("    '%s'," % app_name, 'INSTALLED_APPS')
        settings_edit.commit()
        # TODO urls.py edit: urlpatterns += (controller_method_resource_pattern, route(controller))
        # TODO settings.py edit: app

        


from setuptools import setup
setup(name='djangobp',
      version='1.0',
      packages=['djangobp', 
                'djangobp.management', 
                'djangobp.management.commands', 
                'djangobp.scaffold',
                'djangobp.scaffold.app',
                'djangobp.scaffold.app.controllers',
                'djangobp.scaffold.app.static',
                'djangobp.scaffold.app.templates',
                'djangobp.scaffold.model',
                'djangobp.scaffold.model.controllers',
                'djangobp.scaffold.model.templates',
                'djangobp.scaffold.scaffold',
                'djangobp.scaffold.socialauth',
                'djangobp.scaffold.socialauth.controllers',
                'djangobp.scaffold.socialauth.templates',
                ],
      package_data={'djangobp.scaffold.app.static': ['css/*', 'js/*', 'images/*', 'fancybox/*'],
                    'djangobp.scaffold.app.templates': ['*'],
                    'djangobp.scaffold.model.templates': ['common/*', 'sample/*'],
                    'djangobp.scaffold.socialauth.templates': ['accounts/*'],
                    },
      scripts=['scripts/djangobp-install.py']
      )



#!/usr/bin/env python
from djangobp.editsettings import install_app
import sys
import os
import importlib

if __name__ == "__main__":
    settings = os.getcwd().split('/')[-1] + '.settings'
    sys.path.append('.')
    os.environ.setdefault("DJANGO_SETTINGS_MODULE", settings)
    install_app('djangobp')
